@@ -1,8 +1,9 @@
-from sakkara.model.composable.group.component import GroupComponent
+from sakkara.model.composable.group import GroupComponent
 from sakkara.model.composable.hierarchical.likelihood import Likelihood
 from sakkara.model.composable.hierarchical.distribution import DistributionComponent
 from sakkara.model.composable.hierarchical.deterministic import DeterministicComponent
-from sakkara.model.fixed.base import FixedValueComponent
-from sakkara.model.fixed.data import SeriesComponent, data_components
+from sakkara.model.fixed.base import UnrepeatableComponent
+from sakkara.model.fixed.data import DataComponent, data_components
 from sakkara.model.function import FunctionComponent
 from sakkara.model.utils import build
+from sakkara.model.function_wrapper import f_
